==> calligra_2.7.2.orig.tar.xz: calligra-2.7.2/stage/plugins/pageeffects/edgewipe/zigzagwipe/ZigZagWipeStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef ZIGZAGWIPESTRATEGY_H
#define ZIGZAGWIPESTRATEGY_H

#include <KPrPageEffectStrategy.h>
#include <KPrPageEffect.h>

class ZigZagWipeStrategy : public KPrPageEffectStrategy
{
public:
    ZigZagWipeStrategy( int subtype, const char *smilSubType, bool reverse );
    virtual ~ZigZagWipeStrategy();

    /// reimplemented from KPrPageEffectStrategy
    virtual void setup( const KPrPageEffect::Data &data, QTimeLine &timeLine );
    /// reimplemented from KPrPageEffectStrategy
    virtual void paintStep( QPainter &p, int currPos, const KPrPageEffect::Data &data );
    /// reimplemented from KPrPageEffectStrategy
    virtual void next( const KPrPageEffect::Data &data );

private:
    /// calculates clip path for given step
    QPainterPath clipPath( int step, const QRect &area );
};

#endif // ZIGZAGWIPESTRATEGY_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/plugins/pageeffects/edgewipe/zigzagwipe/ZigZagWipeStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef ZIGZAGWIPESTRATEGY_H
#define ZIGZAGWIPESTRATEGY_H

#include <KPrPageEffectStrategy.h>
#include <KPrPageEffect.h>

class ZigZagWipeStrategy : public KPrPageEffectStrategy
{
public:
    ZigZagWipeStrategy( int subtype, const char *smilSubType, bool reverse );
    ~ZigZagWipeStrategy() override;

    /// reimplemented from KPrPageEffectStrategy
    void setup( const KPrPageEffect::Data &data, QTimeLine &timeLine ) override;
    /// reimplemented from KPrPageEffectStrategy
    void paintStep( QPainter &p, int currPos, const KPrPageEffect::Data &data ) override;
    /// reimplemented from KPrPageEffectStrategy
    void next( const KPrPageEffect::Data &data ) override;

private:
    /// calculates clip path for given step
    QPainterPath clipPath( int step, const QRect &area );
};

#endif // ZIGZAGWIPESTRATEGY_H
